
# q-expansion of newform 288.8.d.d, downloaded from the LMFDB on 11 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 288
weight = 8
poly_data = [3813237677250, 613270661346, -21982316987, -6477861300, 94608296, -78987210, -20463993, 2867784, 349930, -23250, -1005, 300, -52, -6, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-8334859902843625326, -3161357388258480252, 524880822223518929, 7975646361552797, -3355895880261979, -9936853793813, 81802799531178, -17675235421070, 768357205164, 146710834954, -28983151979, 3384637889, -167884787, -2324553], 2010920867856384], [[-363369230726518631430, 3481842996354130900, 1808757388284115749, 169115599797779681, -20660662636751991, 10039784528188743, -33644004780558, -293256687659174, 18519553622556, -809207650350, 115254715449, -26859563563, 7190225169, -594447101], 418271540514127872], [[428482956131706626, 2849385926874852, -5197190315296695, -360054855117963, 48720065815549, -24208962602029, 845509582170, 357185981026, -18215766708, -2798925126, 346825197, -30451335, -7174107, 1256255], 670306955952128], [[-55592758119569467734, -2829353467017697740, 488892118317291837, 31777295062177305, -6592518699840639, 2290922466223311, 79737812279010, -51793529810166, 417110421564, 295776184770, -27635439951, -4871646099, 1839828681, -136458837], 69711923419021312], [[2565499676324173758, -195275779446474036, -28666963174596185, 6343624157049811, -3428305150952381, 153268590227045, 12800895736134, 1208872866734, -133856250444, 45318576806, 1703151875, -2035242449, 158560859, -816519], 251365108482048], [[148259257735814994, 1680215623725566340, 146029389376422065, 34248172103558717, -2426543435992699, -105591755131829, -43439731533462, 2641760912050, -262088748756, 34115189194, 12731384821, -2007047455, 161988589, -11305833], 1005460433928192], [[-811622433327828570810, 27133640698644114092, 7405104295084835451, -511315798413796289, -73982848574293353, 34416885568200345, -59266332384690, -630839368808986, 52723758583140, -1846031897490, -72090066969, -35603446325, 17493542415, -1279597987], 104567885128531968], [[-1721462123747054846, -1101539910855630492, -37514365917414967, 30098296694626357, -1543253774298371, 58222258696979, 5961030713946, 1015125282786, -802108368564, -9175324230, 11109093229, -941992135, 130735397, -8437121], 670306955952128], [[-3189602746090423399842, -133252148551699487396, 64621118980364238951, 1570375894725816635, -1063017205771327245, 91502895226361085, 13525227938198406, -2796361724770946, -115312826387724, 35082654836262, -207846710397, -498215726857, 61874225739, -3419596847], 209135770257063936], [[2575325378479064588766, 131581015116018487388, -45322452597764016601, 755073054997083643, 153597739922353587, -98031095591584195, 5376860054674694, 1985434332393726, -51378933133324, -15412515338330, 1417644867651, -25315357513, -43391939317, 4751865361], 209135770257063936], [[558187164318871182474, 19213165207555361396, -4087915433211505875, -319765439784292727, 11091663311638449, -19031546046532641, -357015331897278, 402579892658282, -13547583980676, -216836346078, -16055626143, 30563864989, -10752905607, 740127227], 26141971282132992], [[13579053159888787554, 62643898583415108, -164967309305418407, -1511782411821035, 2269073729501485, -680624884352077, 11425355286906, 12201306022178, -440856550260, -93574136998, 14650751165, -350099687, -240903595, 20473695], 251365108482048], [[9139546981242037171098, 309012971685667392788, -98250198303214337675, -6941703325253655311, 1285230204817912857, -296715453739896905, -11216875419251438, 8364253406109946, -109866932354084, -50933571228430, 779493268425, 846199751973, -251757155807, 19121720115], 209135770257063936]]

hecke_ring_character_values = [[127, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [37, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [65, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-98, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -4, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, -5, 0, 0, -1, 0, 0, 1, 0, 0, 0], [208, 1, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -56, 0, 20, 0, 0, 0, 0, 1, -1, -1, 0, 1], [-10244, -1, 0, 8, 0, 0, -3, 0, -1, 0, 0, 0, 0, 0], [0, 0, -59, 0, 77, 0, 0, -2, 0, -1, -5, 0, 0, 10], [6389, 1, 0, -8, 0, -3, 0, 0, 2, 0, 0, 0, 2, 0], [0, 0, -168, 0, 182, 0, 0, 6, 0, -5, 23, -5, 0, -14], [31526, -3, 0, 176, 0, 6, -2, 0, -14, 0, 0, 0, 6, 0], [0, 0, -136, 0, 234, 0, 0, 20, 0, 13, 9, 43, 0, -29], [-75439, 29, 0, -111, 0, 15, 5, 0, -14, 0, 0, 0, 15, 0], [0, 0, 815, 0, -1457, 0, 0, -20, 0, -51, 15, 34, 0, 30], [0, 0, 1824, 0, 141, 0, 0, 16, 0, 40, -166, -144, 0, 26], [0, 0, -1696, 0, -146, 0, 0, 280, 0, 13, 67, -1, 0, -2], [0, 0, 1888, 0, -197, 0, 0, -80, 0, 52, 178, -188, 0, -38], [369515, 28, 0, -1419, 0, 21, 10, 0, -69, 0, 0, 0, -39, 0], [-389101, -175, 0, 821, 0, 15, -50, 0, 152, 0, 0, 0, 5, 0], [1026769, 168, 0, 498, 0, 13, 88, 0, -117, 0, 0, 0, -57, 0], [0, 0, 7948, 0, -486, 0, 0, -617, 0, 150, 546, 10, 0, -114], [853726, -84, 0, 3920, 0, -120, 202, 0, -150, 0, 0, 0, 108, 0], [9656, -176, 0, -1222, 0, 50, 76, 0, -464, 0, 0, 0, 190, 0], [0, 0, -13379, 0, 3770, 0, 0, -270, 0, 48, 510, 368, 0, 0], [-5528752, -119, 0, -1017, 0, 150, 186, 0, -403, 0, 0, 0, 155, 0], [0, 0, -11952, 0, 13551, 0, 0, 1040, 0, 270, -312, 730, 0, -108], [0, 0, 22274, 0, -3599, 0, 0, 1971, 0, 110, 79, 556, 0, 1076], [-1758188, -288, 0, -9018, 0, -210, -96, 0, 4, 0, 0, 0, -270, 0], [8261821, -1409, 0, -2558, 0, 65, -14, 0, -308, 0, 0, 0, 310, 0], [0, 0, -6080, 0, -8645, 0, 0, 904, 0, 132, 1020, -1028, 0, 900], [-7876638, -79, 0, 14832, 0, 270, 212, 0, -184, 0, 0, 0, -630, 0], [0, 0, -61736, 0, -21927, 0, 0, 922, 0, 614, 1698, -166, 0, 782], [0, 0, 20667, 0, -39088, 0, 0, -2732, 0, 1632, -660, -2572, 0, 1440], [-19355416, -555, 0, 10777, 0, -318, 958, 0, 397, 0, 0, 0, -353, 0], [0, 0, 30560, 0, -59921, 0, 0, 2171, 0, 1410, 4051, -630, 0, -852], [0, 0, 63392, 0, 23446, 0, 0, 6006, 0, 665, 2563, -905, 0, 1301], [10904852, -1357, 0, 23038, 0, 900, -491, 0, 599, 0, 0, 0, -720, 0], [0, 0, 48067, 0, 86321, 0, 0, -1472, 0, 1449, -4065, -2016, 0, 2982], [0, 0, 150592, 0, 1689, 0, 0, 4528, 0, -1908, -2742, 5980, 0, 2322], [0, 0, 57518, 0, 103474, 0, 0, 4320, 0, 2525, 3307, 7411, 0, 158], [-4258329, -559, 0, 7421, 0, 21, -489, 0, -1724, 0, 0, 0, 1179, 0], [-8116577, -2811, 0, -54943, 0, 195, 2030, 0, 1832, 0, 0, 0, 665, 0], [0, 0, 110175, 0, -104229, 0, 0, 4502, 0, -219, -1203, 10176, 0, 1326], [-2778822, -1385, 0, 1813, 0, -972, 892, 0, -4467, 0, 0, 0, -195, 0], [0, 0, 454200, 0, -67807, 0, 0, -1958, 0, 138, -226, -4330, 0, -1614], [-55111933, 1752, 0, 31974, 0, 575, -6558, 0, -251, 0, 0, 0, -845, 0], [0, 0, 63540, 0, 106364, 0, 0, 6297, 0, 6754, -9778, -706, 0, -1294], [0, 0, 48610, 0, 160968, 0, 0, 25394, 0, -4325, -2805, -14811, 0, 2290], [-141820, -4438, 0, 50534, 0, -2070, 2790, 0, -174, 0, 0, 0, -1230, 0], [35590751, 5253, 0, 8289, 0, -1491, 237, 0, 2684, 0, 0, 0, -6279, 0], [47822413, 3729, 0, 70815, 0, 625, -3642, 0, -5020, 0, 0, 0, 443, 0], [0, 0, -65508, 0, 4556, 0, 0, 10991, 0, 3868, 1088, 5332, 0, -15688], [78788746, -8742, 0, 10704, 0, -660, -750, 0, 14554, 0, 0, 0, 2280, 0], [-142874339, -5392, 0, -148523, 0, 135, -7010, 0, 13453, 0, 0, 0, -1065, 0], [0, 0, -245761, 0, 743434, 0, 0, 34768, 0, -8644, -12524, -10910, 0, -10136], [-45385507, 10588, 0, 50968, 0, 1373, 2678, 0, 443, 0, 0, 0, 6341, 0], [0, 0, 151894, 0, 821990, 0, 0, 484, 0, -9483, -2737, 18987, 0, -4242], [115353536, 12852, 0, -10326, 0, -1206, 9630, 0, -3526, 0, 0, 0, -558, 0], [0, 0, -365896, 0, -59701, 0, 0, 48706, 0, -2106, -26320, -28046, 0, -19716], [0, 0, -432925, 0, -957307, 0, 0, 16276, 0, 2171, -32279, 24466, 0, 4498], [0, 0, 311520, 0, -6309, 0, 0, -28656, 0, -17916, 17394, 5364, 0, -26118], [-126845659, 20458, 0, 204173, 0, 183, 3308, 0, -24937, 0, 0, 0, -4857, 0], [-51720051, 16539, 0, 36155, 0, -7095, -16922, 0, 15796, 0, 0, 0, 835, 0], [0, 0, 716767, 0, 1183624, 0, 0, -61278, 0, -10914, 26064, 10736, 0, 1524], [0, 0, -1370280, 0, 521031, 0, 0, -86986, 0, -11624, 528, -8920, 0, -26528], [302645529, 8123, 0, 210687, 0, -5635, 2602, 0, 26952, 0, 0, 0, 4575, 0], [0, 0, -67820, 0, 305264, 0, 0, 79353, 0, -29034, -30642, -28614, 0, 23034], [0, 0, -558116, 0, -1615380, 0, 0, 26320, 0, 6503, 4161, -3325, 0, -9286], [182606992, 20038, 0, 414990, 0, 1530, -15026, 0, -24070, 0, 0, 0, -9390, 0], [-70427789, -1830, 0, 241505, 0, 6645, -16550, 0, 41565, 0, 0, 0, 723, 0], [125871893, -11219, 0, 177136, 0, -8875, -12046, 0, -5590, 0, 0, 0, 1100, 0], [0, 0, -80748, 0, 2119515, 0, 0, -94693, 0, -12944, 13749, -40804, 0, -19616], [0, 0, 228048, 0, -495568, 0, 0, 182298, 0, -25715, -2875, 62011, 0, 16255], [128551299, -7669, 0, -414795, 0, -975, 17699, 0, -3562, 0, 0, 0, -9855, 0], [0, 0, 87069, 0, -2393815, 0, 0, -1096, 0, -7767, -17241, -88704, 0, -52314], [0, 0, 2574416, 0, -2597267, 0, 0, 78531, 0, 13196, -50543, -30194, 0, -26488], [-340986540, 30919, 0, 44814, 0, -6456, 54844, 0, -18596, 0, 0, 0, 26784, 0], [-48037216, 3116, 0, -87658, 0, 11302, 23060, 0, -35728, 0, 0, 0, 2426, 0], [0, 0, -465804, 0, -4784, 0, 0, 166361, 0, -12734, 20294, 22942, 0, -61174], [0, 0, 903386, 0, 2669486, 0, 0, -60014, 0, -34275, 21113, 79729, 0, -738], [-468518239, -55097, 0, 690177, 0, -12033, -13211, 0, 13752, 0, 0, 0, -20979, 0], [472276804, 19838, 0, -198010, 0, 18450, -18360, 0, -23060, 0, 0, 0, -3530, 0], [-846350372, -40259, 0, -89753, 0, 25242, -14080, 0, -743, 0, 0, 0, 17773, 0], [0, 0, 1404948, 0, 532264, 0, 0, 46793, 0, 39526, 81146, 24826, 0, -18394], [657306820, -43429, 0, 407370, 0, -28740, -13258, 0, -15330, 0, 0, 0, -27840, 0], [513601840, -1988, 0, 216494, 0, 7390, 50048, 0, -4260, 0, 0, 0, 25290, 0], [0, 0, -1564085, 0, 5287195, 0, 0, 83572, 0, -9549, -39855, 34836, 0, 8610], [101999015, 51463, 0, 760384, 0, 2455, -51302, 0, -75778, 0, 0, 0, -49240, 0], [0, 0, -3714508, 0, 2841112, 0, 0, 4737, 0, 76590, -115506, -89630, 0, 97674], [-5438818, 115936, 0, -1122308, 0, -20538, 7560, 0, -16598, 0, 0, 0, -150, 0], [-987814408, -121282, 0, 2619, 0, -18330, 5426, 0, -32952, 0, 0, 0, -40230, 0], [0, 0, 4274704, 0, 318969, 0, 0, -302624, 0, 29706, 119202, 94342, 0, 34518], [0, 0, -2377480, 0, 407059, 0, 0, -390830, 0, 125230, 123976, 111914, 0, 74884], [-781322381, 68552, 0, 938997, 0, 1125, 1580, 0, -73461, 0, 0, 0, -39525, 0], [0, 0, -1913335, 0, 3023565, 0, 0, -292736, 0, -35949, 122469, 113854, 0, 70626], [-340891836, 13911, 0, 1791534, 0, 9144, 86178, 0, -84126, 0, 0, 0, 72876, 0], [0, 0, 1851272, 0, -23994, 0, 0, -179700, 0, -41133, 259377, -103363, 0, 42903], [0, 0, 4241934, 0, -3802678, 0, 0, -377910, 0, 79015, 223751, 265543, 0, -192326], [0, 0, -3043640, 0, 2499646, 0, 0, 496160, 0, 43041, 80185, 2471, 0, -163845], [0, 0, 7213157, 0, 533034, 0, 0, 221878, 0, -21642, -40860, 201418, 0, 167172], [0, 0, -1029596, 0, 730618, 0, 0, -242743, 0, 65784, 66096, 5384, 0, 100992], [1034312274, 38393, 0, 1585740, 0, 11130, 52406, 0, -36190, 0, 0, 0, 32802, 0], [0, 0, 6294552, 0, 5474841, 0, 0, 637414, 0, 162752, -378462, 78376, 0, 45602], [-1990641957, 195157, 0, -3729135, 0, -37645, 135950, 0, -118288, 0, 0, 0, -71935, 0], [0, 0, 2002880, 0, -1288071, 0, 0, 49924, 0, -93570, -304926, -190750, 0, 33342], [-1744563948, -69996, 0, -3169362, 0, 11310, 44244, 0, -26664, 0, 0, 0, -5670, 0], [-3065256314, -70153, 0, 2236310, 0, 3150, -42381, 0, 242525, 0, 0, 0, 57228, 0], [-782806711, -177829, 0, -660901, 0, 30569, 12018, 0, -23176, 0, 0, 0, -25021, 0], [-993535853, -62361, 0, -3193296, 0, -61205, -159596, 0, -112986, 0, 0, 0, -36390, 0], [0, 0, -7227312, 0, 544459, 0, 0, -362943, 0, 243992, -190745, -368878, 0, 59408], [-2128915568, 73430, 0, 2724814, 0, 810, -151088, 0, -96020, 0, 0, 0, -167130, 0], [0, 0, 5437440, 0, -4025503, 0, 0, -439192, 0, 12476, 24260, 376452, 0, 65660], [1672339352, -59868, 0, 4440031, 0, 12086, 51948, 0, 6286, 0, 0, 0, 137794, 0], [2344650070, 166443, 0, -2935400, 0, -90750, -147064, 0, -55180, 0, 0, 0, 44286, 0], [0, 0, 6225296, 0, 4202372, 0, 0, -1300586, 0, 62199, 285245, -127751, 0, 163851], [-3085512024, 221715, 0, 530556, 0, -73620, 243291, 0, -233613, 0, 0, 0, 147570, 0], [0, 0, -2270013, 0, -2728779, 0, 0, -1058228, 0, 104745, 498099, -308200, 0, -122106], [0, 0, -14175200, 0, 11339057, 0, 0, -2596, 0, -123954, 226122, -19534, 0, -192762], [0, 0, 10994656, 0, -5459027, 0, 0, -483991, 0, -175878, -300371, 495914, 0, 225276], [-1360371968, 30966, 0, 886658, 0, 99950, -228416, 0, 230060, 0, 0, 0, 145610, 0], [0, 0, -3323421, 0, 7260422, 0, 0, -887180, 0, 16850, -29846, 620960, 0, -298964], [0, 0, -3867380, 0, 2538502, 0, 0, 458959, 0, -45326, 212834, 163774, 0, -40858], [0, 0, 8436384, 0, -3335846, 0, 0, 615782, 0, -207831, -753953, -258185, 0, -53967], [0, 0, -1801461, 0, -249782, 0, 0, 2087172, 0, 267600, -741396, 608602, 0, 127776], [0, 0, -13311154, 0, -16366762, 0, 0, -941906, 0, -321987, -230275, 85237, 0, -211170], [6280265698, -135066, 0, 3996896, 0, -105894, 218002, 0, -257364, 0, 0, 0, 51246, 0], [-97401204, 236335, 0, -738755, 0, -104690, 135710, 0, -228729, 0, 0, 0, -40095, 0], [0, 0, -17868958, 0, 11715100, 0, 0, 1177364, 0, -289887, -460589, 535473, 0, -86730], [0, 0, 5821944, 0, 9454573, 0, 0, 649686, 0, -374404, -495842, 408236, 0, -29578], [-6793634424, 19219, 0, -4281026, 0, -51000, -193359, 0, -82021, 0, 0, 0, -27360, 0], [3749010737, 757148, 0, 1917814, 0, -11371, 303952, 0, -53601, 0, 0, 0, -3645, 0], [0, 0, 19249378, 0, -10557234, 0, 0, -874596, 0, 263469, -460833, -171821, 0, -688386], [2296451724, 226149, 0, -2386586, 0, 105684, 156014, 0, 99334, 0, 0, 0, -13704, 0], [-438611021, -131967, 0, 9089021, 0, 76951, 930, 0, 289556, 0, 0, 0, -73171, 0], [0, 0, -28882199, 0, 17424042, 0, 0, -1513638, 0, -137068, 149458, 266252, 0, 232600], [0, 0, 28360336, 0, -18608480, 0, 0, -747758, 0, 268609, 921073, -34841, 0, -1136525], [0, 0, -2383659, 0, -32723030, 0, 0, -1004920, 0, -490194, -532614, -382884, 0, 302964], [666745214, -426365, 0, -4231776, 0, -18006, -27794, 0, -252246, 0, 0, 0, -99150, 0], [0, 0, -29314560, 0, 5609122, 0, 0, 1592346, 0, -193309, 613411, 121589, 0, -37111], [0, 0, 6844265, 0, 31554898, 0, 0, 437304, 0, -240076, -1369676, -332454, 0, 27256], [-10353138938, 145884, 0, -3785711, 0, -38560, -184282, 0, -79704, 0, 0, 0, -367170, 0], [0, 0, -4888320, 0, 11686259, 0, 0, -1578316, 0, 369394, -306136, 31174, 0, 1361852], [0, 0, -9772878, 0, 41446099, 0, 0, 155685, 0, -130912, -601157, -1675834, 0, 5312], [-4559830869, 416184, 0, -6804935, 0, -162675, -120442, 0, -155825, 0, 0, 0, 122073, 0], [0, 0, 35790112, 0, -27123905, 0, 0, 839095, 0, -127592, -235343, 1485868, 0, 608848], [-2092103002, 151251, 0, -2620476, 0, 77550, -739464, 0, -201220, 0, 0, 0, 72450, 0], [0, 0, -18409216, 0, -14352934, 0, 0, -2013122, 0, 309249, -1625053, 644911, 0, -332667], [4784235437, -143261, 0, -10061241, 0, -99225, 14617, 0, -596052, 0, 0, 0, -193755, 0], [0, 0, 8645340, 0, 28504074, 0, 0, 142082, 0, -308111, 1091157, 79289, 0, -745514], [-1305257822, -34902, 0, 9707216, 0, -98964, 182230, 0, 77406, 0, 0, 0, -61488, 0], [0, 0, 38604760, 0, -24375032, 0, 0, 1329984, 0, -371341, -114221, 471429, 0, 599417], [-8379728571, 170846, 0, 6185913, 0, 107055, 205340, 0, -617845, 0, 0, 0, 417915, 0], [0, 0, -16209680, 0, 25877806, 0, 0, 705050, 0, 162513, 1623355, 1029503, 0, 161085], [10292434447, 45423, 0, 10113525, 0, -381195, -570039, 0, -147950, 0, 0, 0, -194205, 0], [-10427542460, 273874, 0, 7062739, 0, 307914, 326084, 0, -115076, 0, 0, 0, 787168, 0], [-7699768352, 499617, 0, 2431318, 0, -279252, -13654, 0, 607778, 0, 0, 0, -490200, 0], [-6713674130, -981816, 0, 393032, 0, -16360, -171704, 0, -237688, 0, 0, 0, 18440, 0], [0, 0, -6115497, 0, -14520625, 0, 0, -3088634, 0, 815727, 105315, 304022, 0, -366390], [0, 0, 8997360, 0, 16842689, 0, 0, -351100, 0, -1142472, 1073250, 1393408, 0, -891390], [-2239843772, -271969, 0, -744210, 0, -442200, 473354, 0, -238518, 0, 0, 0, 1260, 0], [-11019099052, 181066, 0, 1779841, 0, -1530, 853344, 0, 25520, 0, 0, 0, -391360, 0], [0, 0, -20229764, 0, -27782434, 0, 0, 3483251, 0, 125790, 1590438, -858286, 0, 978882], [8193718560, -326643, 0, -9573026, 0, 221340, -54874, 0, -837986, 0, 0, 0, 673200, 0], [-15074873675, 564362, 0, -2602703, 0, -356625, 32596, 0, 546223, 0, 0, 0, -131865, 0], [9368370687, -765166, 0, 5511544, 0, 162919, 160324, 0, 61519, 0, 0, 0, -578825, 0], [0, 0, -78218304, 0, -9066782, 0, 0, 930460, 0, 847531, 854161, -653139, 0, 519634]]
